Version 0.2.0 (2015-12-11):
 * Ability to calculate and plot particle velocity and displacement fields
 * Several function name and parameter name changes
 * Several refactorings, bugfixes and other improvements

Version 0.1.1 (2015-10-08):
 * Fix missing `sfs.mono` subpackage in PyPI packages

Version 0.1.0 (2015-09-22):
   Initial release.
